API
***

Here you can find the full API documentation of the Balder Framework.

.. toctree::
    :maxdepth: 2
    :caption: API

    decorator.rst
    plugin.rst
    connections.rst
    devices.rst
    features.rst
    balderglob.rst
    scenarios.rst
    setups.rst
    controllers.rst
    parametrization.rst
